import { Component, signal, ChangeDetectionStrategy, inject, WritableSignal } from '@angular/core';
import { UserService } from './user.service';
import { NgFor, NgIf } from '@angular/common';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [NgFor, NgIf],
  templateUrl: './app.component.html',
  styleUrl: './app.component.css',
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class AppComponent {
  title = 'angular-workshop';
  
  private userService = inject(UserService);
  
  selectedUserId = signal<number | null>(null);

  users: WritableSignal<any[]> = signal([]);
  
  todos: WritableSignal<any[]> = signal([]);

  isLoadingUsers = signal(true);
  isLoadingTodos = signal(false);
  
  ngOnInit() {
    this.userService.getUsers().subscribe(users => {
      this.users.set(users);
      this.isLoadingUsers.set(false)
    });
  }
  
  onUserSelect(event: Event): void {
    const userId = Number((event.target as HTMLSelectElement).value);
    this.selectedUserId.set(userId);
    this.isLoadingTodos.set(true);
    this.userService.getTodos(userId).subscribe({
      next: (todos) => this.todos.set(todos),
      error: () => this.isLoadingTodos.set(false),
      complete: () => this.isLoadingTodos.set(false)
    });
  }
}
